gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[taler-exchange] 02/02: denom->amount


From: gnunet
Subject: [taler-exchange] 02/02: denom->amount
Date: Sun, 19 Jan 2020 22:01:34 +0100

This is an automated email from the git hooks/post-receive script.

dold pushed a commit to branch master
in repository exchange.

commit 12468e1fd89748aaa4b1d31052e97e2436b763c4
Author: Florian Dold <address@hidden>
AuthorDate: Sun Jan 19 22:01:20 2020 +0100

    denom->amount
---
 src/include/taler_amount_lib.h | 25 +++++++++++++------------
 src/util/amount.c              | 29 +++++++++++++++--------------
 2 files changed, 28 insertions(+), 26 deletions(-)

diff --git a/src/include/taler_amount_lib.h b/src/include/taler_amount_lib.h
index e3f39cbb..f088d89b 100644
--- a/src/include/taler_amount_lib.h
+++ b/src/include/taler_amount_lib.h
@@ -113,42 +113,43 @@ struct TALER_Amount
 
 
 /**
- * Parse denomination description, in the format "T:V.F".
+ * Parse monetary amount, in the format "T:V.F".
  *
- * @param str denomination description
- * @param[out] denom denomination to write the result to
- * @return #GNUNET_OK if the string is a valid denomination specification,
+ * @param str amount string
+ * @param[out] amount amount to write the result to
+ * @return #GNUNET_OK if the string is a valid monetary amount specification,
  *         #GNUNET_SYSERR if it is invalid.
  */
 int
 TALER_string_to_amount (const char *str,
-                        struct TALER_Amount *denom);
+                        struct TALER_Amount *amount);
 
 
 /**
- * Parse denomination description, in the format "T:V.F".
+ * Parse monetary amount, in the format "T:V.F".
+ * The result is stored in network byte order (NBO).
  *
  * @param str denomination description
  * @param[out] denom denomination to write the result to, in NBO
  * @return #GNUNET_OK if the string is a valid denomination specification,
  *         #GNUNET_SYSERR if it is invalid.
  */
 int
 TALER_string_to_amount_nbo (const char *str,
-                            struct TALER_AmountNBO *denom);
+                            struct TALER_AmountNBO *amount_nbo);
 
 
 /**
  * Get the value of "zero" in a particular currency.
  *
  * @param cur currency description
- * @param[out] denom denomination to write the result to
+ * @param[out] amount amount to write the result to
  * @return #GNUNET_OK if @a cur is a valid currency specification,
  *         #GNUNET_SYSERR if it is invalid.
  */
 int
 TALER_amount_get_zero (const char *cur,
-                       struct TALER_Amount *denom);
+                       struct TALER_Amount *amount);
 
 
 /**
@@ -113,42 +113,43 @@ struct TALER_Amount
  *
- * @param str denomination description
- * @param[out] denom denomination to write the result to, in NBO
- * @return #GNUNET_OK if the string is a valid denomination specification,
+ * @param str amount string
+ * @param[out] amount_nbo amount to write the result to
+ * @return #GNUNET_OK if the string is a valid amount specification,
  *         #GNUNET_SYSERR if it is invalid.
  */
diff --git a/src/util/amount.c b/src/util/amount.c
index d5789c1d..c15eeaaf 100644
--- a/src/util/amount.c
+++ b/src/util/amount.c
@@ -45,11 +45,11 @@ invalidate (struct TALER_Amount *a)
 
 
 /**
- * Parse money amount description, in the format "A:B.C".
+ * Parse monetary amount, in the format "T:V.F".
  *
- * @param str amount description
- * @param[out] denom amount to write the result to
- * @return #GNUNET_OK if the string is a valid amount specification,
+ * @param str amount string
+ * @param[out] amount amount to write the result to
+ * @return #GNUNET_OK if the string is a valid monetary amount specification,
  *         #GNUNET_SYSERR if it is invalid.
  */
 int
@@ -181,16 +181,17 @@ TALER_string_to_amount (const char *str,
 
 
 /**
- * Parse denomination description, in the format "T:V.F".
+ * Parse monetary amount, in the format "T:V.F".
+ * The result is stored in network byte order (NBO).
  *
  * @param str denomination description
  * @param[out] denom denomination to write the result to, in NBO
  * @return #GNUNET_OK if the string is a valid denomination specification,
  *         #GNUNET_SYSERR if it is invalid.
  */
 int
 TALER_string_to_amount_nbo (const char *str,
-                            struct TALER_AmountNBO *denom)
+                            struct TALER_AmountNBO *amount_nbo)
 {
   struct TALER_Amount amount;
 
@@ -198,7 +199,7 @@ TALER_string_to_amount_nbo (const char *str,
       TALER_string_to_amount (str,
                               &amount))
     return GNUNET_SYSERR;
-  TALER_amount_hton (denom,
+  TALER_amount_hton (amount_nbo,
                      &amount);
   return GNUNET_OK;
 }
@@ -248,23 +249,23 @@ TALER_amount_ntoh (struct TALER_Amount *res,
  * Get the value of "zero" in a particular currency.
  *
  * @param cur currency description
- * @param[out] denom denomination to write the result to
+ * @param[out] amount amount to write the result to
  * @return #GNUNET_OK if @a cur is a valid currency specification,
  *         #GNUNET_SYSERR if it is invalid.
  */
 int
 TALER_amount_get_zero (const char *cur,
-                       struct TALER_Amount *denom)
+                       struct TALER_Amount *amount)
 {
   size_t slen;
 
   slen = strlen (cur);
   if (slen >= TALER_CURRENCY_LEN)
     return GNUNET_SYSERR;
-  memset (denom,
+  memset (amount,
           0,
           sizeof (struct TALER_Amount));
-  memcpy (denom->currency,
+  memcpy (amount->currency,
           cur,
           slen);
   return GNUNET_OK;
@@ -181,16 +181,17 @@ TALER_string_to_amount (const char *str,
  *
- * @param str denomination description
- * @param[out] denom denomination to write the result to, in NBO
- * @return #GNUNET_OK if the string is a valid denomination specification,
+ * @param str amount string
+ * @param[out] amount_nbo amount to write the result to
+ * @return #GNUNET_OK if the string is a valid amount specification,
  *         #GNUNET_SYSERR if it is invalid.
  */

-- 
To stop receiving notification emails like this one, please contact
address@hidden.



reply via email to

[Prev in Thread] Current Thread [Next in Thread]